from telegram_pydantic.models.inline_mode.inline_query import InlineQuery
from telegram_pydantic.models.inline_mode.chosen_inline_result import ChosenInlineResult

__all__ = ["InlineQuery", "ChosenInlineResult"]
