from telegram_pydantic.models.input_media.input_media import InputMedia
from telegram_pydantic.models.input_media.input_media_audio import InputMediaAudio
from telegram_pydantic.models.input_media.input_media_video import InputMediaVideo
from telegram_pydantic.models.input_media.input_media_document import InputMediaDocument
from telegram_pydantic.models.input_media.input_media_animation import InputMediaAnimation

__all__ = ["InputMedia", "InputMediaAudio", "InputMediaVideo", "InputMediaDocument", "InputMediaAnimation"]
